Learn R Programming

EFA.dimensions (version 0.1.8.8)

EFA.dimensions-package: EFA.dimensions

Description

This package provides exploratory factor analysis-related functions for an assortment of factor analysis-related procedures.

There are 11 functions for determining the number of factors (DIMTESTS, EMPKC, HULL, MAP, NEVALSGT1, PARALLEL, RAWPAR, ROOTFIT, SALIENT, SCREE_PLOT, SESCREE, and SMT).

There is a principal components analysis function (PCA), an exploratory factor analysis function (EFA), a bifactor analysis function (BIFACTOR), and an extension factor analysis function (EXTENSION_FA), all with 9 possible factor extraction methods and 12 possible factor rotation methods.

Most of the analyses can be conducted using raw data or correlation matrices as input.

The analyses can be conducted using Pearson correlations, Kendall correlations, Spearman correlations, Goodman-Kruskal gamma correlations (Thompson, 2006), or polychoric correlations (using the psych and polychor packages).

Additional functions include:

  • COMPLEXITY, for the assessment of factor solution complexity

  • CONGRUENCE, for the congruences between factors from different datasets

  • CORRECTED_CORRELS, correcting Pearson correlation coefficients for attenuation due to unreliability

  • ESEM, for exploratory structural equation measurement models

  • FACTORABILITY, for the factorability of a correlation matrix

  • Factorial_Invariance, for factorial invariance

  • LOCALDEP, for the assessment of local independence

  • INTERNAL_CONSISTENCY, for internal consistency statistics

Arguments

References

Auerswald, M., & Moshagen, M. (2019). How to determine the number of factors to retain in exploratory factor analysis: A comparison of extraction methods under realistic conditions. Psychological Methods, 24(4), 468-491.

Mulaik, S. A. (2010). Foundations of factor analysis (2nd ed.). Boca Raton, FL: Chapman and Hall/CRC Press, Taylor & Francis Group.

O'Connor, B. P. (2000). SPSS and SAS programs for determining the number of components using parallel analysis and Velicer's MAP test. Behavior Research Methods, Instrumentation, and Computers, 32, 396-402.

O'Connor, B. P. (2000). SPSS and SAS programs for determining the number of components using parallel analysis and Velicer's MAP test. Behavior Research Methods, Instrumentation, and Computers, 32, 396-402.

Sellbom, M., & Tellegen, A. (2019). Factor analysis in psychological assessment research: Common pitfalls and recommendations. Psychological Assessment, 31(12), 1428-1441.

Watts, A. L., Greene, A. L., Ringwald, W., Forbes, M. K., Brandes, C. M., Levin-Aspenson, H. F., & Delawalla, C. (2023). Factor analysis in personality disorders research: Modern issues and illustrations of practical recommendations. Personality Disorders: Theory, Research, and Treatment, 14(1), 105-117. https://doi.org/10.1037/per0000581