Learn R Programming

EFA.dimensions (version 0.1.8.8)

OMEGA: Omega internal consistency reliability coefficients

Description

Total and hierarchical omega internal consistency reliability coefficients computed using multiple possible methods

Usage

OMEGA(data, corkind = 'pearson',  
      bifactor_kind = c('McD', 'SL', 'SLiD', 'DSL', 
                        'bifactorT', 'bigeominT'),
      EFA_options    = list(extraction = 'minres', 
                            rotation = 'oblimin', 
                            Nfactors = 3),
      schmid_options = list(extraction = 'minres', 
                            rotation = 'oblimin', 
                            N_group_factors = 3),
      delta = .01, min_loading = .2, display = 2)

Value

A list with the omega coefficients, the factor loadings, and model fit statistics.

Arguments

data

An all-numeric dataframe where the rows are cases & the columns are the variables, or a correlation matrix with ones on the diagonal. The function internally determines whether the data are a correlation matrix.

corkind

The kind of correlation matrix to be used if data is not a correlation matrix. The options are 'pearson', 'kendall', 'spearman', 'gamma', and 'polychoric'. Required only if the entered data is not a correlation matrix.

bifactor_kind

The bifactor method(s) to be used. The options are 'McD', 'SL', 'SLiD', 'GPA', 'DSL', 'bifactorQ', 'bifactorT', 'bigeominQ', and 'bigeominT'). Multiple methods can be specified.

EFA_options

(optional) A list with EFA options when rawdata is provided. The list elements must include values for 'extraction', 'rotation', and 'Nfactors'.

The possibilities for extraction are: 'minres'(the default), 'alpha', 'fullinfo', 'gls', 'image', 'ml', 'ols', 'paf', 'uls', and 'wls'.

The possibilities for rotation are: 'varimax', 'bentlerT', 'entropy', 'equamax', 'geominT', 'quartimax', 'promax', 'bentlerQ', 'geominQ', 'oblimin' (the default, 'oblimax', 'quartimin', 'simplimax', and 'none'.

Nfactors is the number of factors to be extracted in the preliminary EFA (i.e., prior to the bifactor analysis).
It should be equal to the number of group factors + 1.

schmid_options

(optional) A list with schmid function (from the psych package) options when bifactor_kind is one of 'SL', 'SLiD', or 'DSL'. The list elements must include values for 'extraction', 'rotation', and 'N_group_factors'.

The possibilities for extraction are: 'minres'(the default), 'paf', 'pc', and 'ml'.

The possibilities for rotation are: 'oblimin' (the default), 'simplimax', 'Promax', 'promax', and 'none'.

N_group_factors is the number of group factors for the bifactor analysis.

delta

When bifactor_kind = 'bigeominT' or 'bigeominQ', delta is a tuning parameter for the Geomin criterion. It acts as a small constant that is added to prevent mathematical problems when a factor loading is exactly zero. Delta is sometimes referred to as 'epsilon'.

min_loading

The minimum value of a group factor loading for an item to be considered to have a non-negligible contribution to a group factor. min_loading only plays a role in some group factor statistics.

display

The results to be displayed in the console:
0 = nothing
1 = only the omega and scale coefficients
2 (default) = detailed output, including the bifactor model loadings and statistics

Author

Brian P. O'Connor

Details

Run one of the following commands for detailed descriptions of the omega-total and omega-hierarchical internal consistency reliability coefficients and other statistics produced by this function:

  • RShowDoc("Coefficient_descriptions_vignettes", package = "EFA.dimensions")

  • vignette("Coefficient_descriptions_vignettes")

For the bifactor_kind argument:

  • McD produces the McDonald's omega_total based on a one-factor EFA rather than on bifactor analyses. omega_hierarchical is not computed.

  • SL produces omega_total and omega_hierarchical based on the Schmid-Leiman transformation of initial EFA output. The psych package (Revelle, 2026) is used for the Schmid-Leiman transformation.

  • SLiD produces omega_total and omega_hierarchical based on the iterative empirical target rotation of an initial Schmid-Leiman solution method. The code was provided by Garcia-Garzon et al. (2021).

  • DSL produces omega_total and omega_hierarchical based on the Direct Schmid-Leiman transformation of initial EFA output, following Waller (2018). The psych package (Revelle, 2026) is used for the Direct Schmid-Leiman transformation.

  • bifactorT produces omega_total and omega_hierarchical based on bifactorT rotation implemented in the GPArotation package (Bernaard & Jennrich, 2026).

  • bifactorQ produces omega_total and omega_hierarchical based on bifactorQ rotation implemented in the GPArotation package (Bernaard & Jennrich, 2026).

  • bigeominT produces omega_total and omega_hierarchical based on bigeominT rotation implemented in the GPArotation package (Bernaard & Jennrich, 2026).

  • bigeominQ produces omega_total and omega_hierarchical based on bigeominQ rotation implemented in the GPArotation package (Bernaard & Jennrich, 2026).

References

Bernaards, C. A., & Jennrich, R. I. (2005). Gradient Projection Algorithms and Software for Arbitrary Rotation Criteria in Factor Analysis. Educational and Psychological Measurement, 65(5), 676-696.

Bernaards, C. A., & Jennrich, R. I. (2026). GPArotation: Gradient Projection Factor Rotation. R package version 2026.4-1, https://CRAN.R-project.org/package=GPArotation

Educational Content Team. (2026). McDonald's Omega. Cogn-IQ Encyclopedia. https://pubscience.org/cqep.2025.0048

Flora, D. B. (2020). Your coefficient alpha is probably wrong, but which coefficient omega is right? A tutorial on using R to obtain better reliability estimates. Advances in Methods and Practices in Psychological Science, 3(4), 484501.

Garcia-Garzon, E., Abad, F. J., & Garrido, L. E. (2021). On omega hierarchical estimation: A Comparison of Exploratory Bi-Factor Analysis Algorithms. Multivariate Behavioral Research, 56(1), 101-119.

Jennrich, R. I. (2018). Rotation. In P. Irwing, T. Booth, & D. J. Hughes (Eds.), The Wiley handbook of psychometric testing: A multidisciplinary reference on survey, scale and test development (pp. 279304). Wiley Blackwell. https://doi.org/10.1002/9781118489772.ch10

Kalkbrenner, M. T. (2024). Choosing Between Cronbachs Coefficient Alpha, McDonalds Coefficient Omega, and Coefficient H: Confidence Intervals and the Advantages and Drawbacks of Interpretive Guidelines. Measurement and Evaluation in Counseling and Development, 57(2), 93105.

McNeish, D. (2018). Thanks coefficient alpha, we'll take it from here. Psychological Methods, 23(3), 412433.

Revelle, W. (2026). psych: Procedures for Psychological, Psychometric, and Personality Research. R package version 2.6.5, https://CRAN.R-project.org/package=psych

Revelle, W., & Condon, D. M. (2019). Reliability from alpha to omega: A tutorial. Psychological Assessment, 31(12), 13951411.

Waller, N. G. (2018) Direct Schmid-Leiman Transformations and Rank-Deficient Loadings Matrices. Psychometrika, 83(4), 858870.

Examples

Run this code
OMEGA(data_RSE, display = 1)
# \donttest{
# }

Run the code above in your browser using DataLab