View source: R/PLOT_Invariance.R
| PLOT_Invariance | R Documentation |
Plots factor loadings, slopes and intercepts, and/or latent variable distributions from multiple groups confirmatory factor analysis (CFA) models and exploratory structural equation models (ESEM)
PLOT_Invariance(model_object,
invar_model = 'Scalar',
plot_types = c('loadings', 'ints_slopes', 'LV_distribs'),
loadings_std = TRUE, loadings_by_factor = FALSE)
model_object |
A "Factorial_Invariance" function output object, or a lavaan multiple groups cfa output object. |
invar_model |
The kind of invariance model for the plots when model_object is from the Factorial_Invariance function. The options are: 'Configural', 'Metric', 'Scalar', 'Strict', 'LV_vars', 'LV_covars', and 'LV_means'. (This argument can be ignored when model_object is not from the Factorial_Invariance function.) |
plot_types |
The desired kind(s) of plots. The possibilities are
|
loadings_std |
Should standardized loadings be used for 'loadings' plots? TRUE or FALSE |
loadings_by_factor |
For 'loadings' plots, should a separate plot be produced for each factor (TRUE)? If FALSE, then the loadings for different factors will appear in the same plots. |
A list containing the following components (if plotted using this function): loadings, estimates, & LV_scores.
Brian P. O'Connor
RSE_output <-
Factorial_Invariance(data = data_RSE_sex, group = 'gender',
LV_keys = c(1, 1, 2, 1, 2, 1, 1, 2, 2, 2),
LV_names = c('pos', 'neg'))
PLOT_Invariance(model_object = RSE_output,
invar_model = 'Configural',
plot_types = c('loadings', 'ints_slopes'),
loadings_std = TRUE, loadings_by_factor = TRUE)
HS_1939_output <-
Factorial_Invariance(data = data_HS_1939, group = 'school',
LV_keys = c(1,1,1, 2,2,2, 3,3,3),
LV_names = c('visual', 'textual', 'speed'))
PLOT_Invariance(model_object = HS_1939_output,
invar_model = 'Scalar',
plot_types = c('LV_distribs'))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.